;; Generated package description from dracula-theme.el  -*- no-byte-compile: t -*-
(define-package "dracula-theme" "1.8.2.0.20250623.191535" "Dracula Theme" '((emacs "24.3")) :commit "3309ca6b7cbc3fd2fd0064f09cdf9a2c20b7e342" :maintainer '("tienne Deparis" . "etienne@depar.is") :url "https://github.com/dracula/emacs")
